OC.L10N.register(
    "spreed",
    {
    "a conversation" : "razgovor",
    "(Duration %s)" : "(Trajanje %s)",
    "You attended a call with {user1}" : "Sudjelovali ste u pozivu s {user1}",
    "_%n guest_::_%n guests_" : ["%n gost","%n gostiju","%n gostiju"],
    "You attended a call with {user1} and {user2}" : "Sudjelovali ste u pozivu s {user1} i {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Sudjelovali ste u pozivu s {user1}, {user2} i {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Sudjelovali ste u pozivu s {user1}, {user2}, {user3} i {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Sudjelovali ste u pozivu s {user1}, {user2}, {user3}, {user4} i {user5}",
    "_%n other_::_%n others_" : ["još %n","još %n","još %n"],
    "{actor} invited you to {call}" : "{actor} vas je pozvao u {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Pozvani ste u <strong>razgovor</strong> ili ste sudjelovali u <strong>pozivu</strong>",
    "Other activities" : "Druge aktivnosti",
    "Talk" : "Razgovor",
    "Guest" : "Gost",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Sada možete upotrebljavati Microsoft Edge i Safari za sudjelovanje u glasovnim i videopozivima",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Razgovori jedan na jedan sada su zaštićeni i više se ne mogu slučajno pretvoriti u grupne razgovore. Također se razgovor više ne briše automatski ako jedan od sudionika napusti razgovor. Razgovor se briše s poslužitelja samo ako ga napuste oba sudionika",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Sada možete obavijestiti sve sudionike slanjem „@all” u prozor za razmjenu poruka",
    "- With the \"arrow-up\" key you can repost your last message" : "- Možete ponovno objaviti posljednju poruku s pomoću tipke sa strelicom prema gore",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk sada ima naredbe, unesite „/help” u prozor za razmjenu poruka kako biste vidjeli naredbe koje je konfigurirao vaš administrator",
    "- With projects you can create quick links between conversations, files and other items" : "- Koristite se projektima za stvaranje brzih poveznica između razgovora, datoteka i drugih stavki",
    "- You can now mention guests in the chat" : "- Sada možete navesti goste u prozoru za razmjenu poruka",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Razgovori sada mogu imati predvorje. To omogućuje moderatorima da se priključe razmjeni poruka i pozivima kako bi pripremili sastanak dok korisnici i gosti čekaju",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Sada možete izravno odgovarati na poruke kako biste drugim korisnicima pružili dodatni kontekst za svoje poruke",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Značajka traženja razgovora i sudionika sada će filtrirati vaše postojeće razgovore radi lakšeg traženja prethodnih razgovora",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Sada možete dodati prilagođene grupe korisnika u razgovore ako je instalirana aplikacija za upravljanje krugovima",
    "- Check out the new grid and call view" : "- Isprobajte nove prikaze rešetke i poziva",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Sada možete otpremati i povlačiti datoteke izravno sa svog uređaja u prozor za razmjenu poruka",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Dijeljene datoteke sada možete otvarati izravno u prikazu za razmjenu poruka s pomoću odgovarajućih preglednika",
    "- You can now search for chats and messages in the unified search in the top bar" : "- sada možete pretraživati poruke putem objedinjenog pretraživača u gornjoj traci",
    "- Spice up your messages with emojis from the emoji picker" : "- začinite svoje poruke emojijima iz alata za odabir emojija",
    "- You can now change your camera and microphone while being in a call" : "- sada možete promijeniti kameru i mikrofon tijekom poziva",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Predstavite svoje razgovore unosom opisa i otvorite ih kako bi ih prijavljeni korisnici mogli pronaći i pridružiti se",
    "- See a read status and send failed messages again" : "- Prikaži status čitanja i ponovno pošalji neuspješne poruke",
    "- Raise your hand in a call with the R key" : "- Podignite ruku u pozivu pritiskom gumba R",
    "- Join the same conversation and call from multiple devices" : "- Pridružite se istom razgovoru i zovite s više uređaja",
    "- Send voice messages, share your location or contact details" : "- Šaljite glasovne poruke, dijelite svoju lokaciju ili podatke za kontakt",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Dodajte grupe u razgovor i novi će se članovi grupe automatski dodati kao sudionici",
    "Talk updates ✅" : "Ažuriranja aplikacije Talk ✅",
    "{actor} created the conversation" : "{actor} je stvorio razgovor",
    "You created the conversation" : "Stvorili ste razgovor",
    "An administrator created the conversation" : "Administrator je stvorio razgovor",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} je preimenovao razgovor iz „%1$s” u „%2$s”",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Preimenovali ste razgovor iz „%1$s” u „%2$s”",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Administrator je preimenovao razgovor iz „%1$s” u „%2$s”",
    "{actor} set the description" : "{actor} je postavio opis",
    "You set the description" : "Vi ste postavili opis",
    "An administrator set the description" : "Administrator je postavio opis",
    "{actor} removed the description" : "{actor} je uklonio opis",
    "You removed the description" : "Vi ste uklonili opis",
    "An administrator removed the description" : "Administrator je uklonio opis",
    "You started a call" : "Pokrenuli ste poziv",
    "{actor} started a call" : "{actor} je pokrenuo poziv",
    "{actor} joined the call" : "{actor} se pridružio pozivu",
    "You joined the call" : "Pridružili ste se pozivu",
    "{actor} left the call" : "{actor} je napustio poziv",
    "You left the call" : "Napustili ste poziv",
    "{actor} unlocked the conversation" : "{actor} je otključao razgovor",
    "You unlocked the conversation" : "Otključali ste razgovor",
    "An administrator unlocked the conversation" : "Administrator je otključao razgovor",
    "{actor} locked the conversation" : "{actor} je zaključao razgovor",
    "You locked the conversation" : "Zaključali ste razgovor",
    "An administrator locked the conversation" : "Administrator je zaključao razgovor",
    "{actor} limited the conversation to the current participants" : "{actor} je ograničio razgovor na trenutne sudionike",
    "You limited the conversation to the current participants" : "Ograničili ste razgovor na trenutne sudionike",
    "An administrator limited the conversation to the current participants" : "Administrator je ograničio razgovor na trenutne sudionike",
    "{actor} opened the conversation to registered users" : "{actor} je otvorio razgovor registriranim korisnicima",
    "You opened the conversation to registered users" : "Otvorili ste razgovor registriranim korisnicima",
    "An administrator opened the conversation to registered users" : "Administrator je otvorio razgovor registriranim korisnicima",
    "The conversation is now open to everyone" : "Razgovor je sada otvoren svima",
    "{actor} opened the conversation to everyone" : "{actor} je otvorio razgovor svima",
    "You opened the conversation to everyone" : "Vi ste otvorili razgovor svima",
    "{actor} restricted the conversation to moderators" : "{actor} je ograničio razgovor samo na moderatore",
    "You restricted the conversation to moderators" : "Vi ste ograničili razgovor samo na moderatore",
    "{actor} allowed guests" : "{actor} je dopustio pristup gostima",
    "You allowed guests" : "Dopustili ste pristup gostima",
    "An administrator allowed guests" : "Administrator je dopustio pristup gostima",
    "{actor} disallowed guests" : "{actor} je zabranio pristup gostima",
    "You disallowed guests" : "Zabranili ste pristup gostima",
    "An administrator disallowed guests" : "Administrator je zabranio pristup gostima",
    "{actor} set a password" : "{actor} je postavio zaporku",
    "You set a password" : "Postavili ste zaporku",
    "An administrator set a password" : "Administrator je postavio zaporku",
    "{actor} removed the password" : "{actor} je uklonio zaporku",
    "You removed the password" : "Uklonili ste zaporku",
    "An administrator removed the password" : "Administrator je uklonio zaporku",
    "{actor} added {user}" : "{actor} je dodao {user}",
    "You joined the conversation" : "Pridružili ste se razgovoru",
    "{actor} joined the conversation" : "{actor} se pridružio razgovoru",
    "You added {user}" : "Dodali ste {user}",
    "{actor} added you" : "Dodao vas je {actor}",
    "An administrator added you" : "Administrator vas je dodao",
    "An administrator added {user}" : "Administrator je dodao {user}",
    "You left the conversation" : "Napustili ste razgovor",
    "{actor} left the conversation" : "{actor} je napustio razgovor",
    "{actor} removed {user}" : "{actor} je uklonio {user}",
    "You removed {user}" : "Uklonili ste {user}",
    "{actor} removed you" : "{actor} vas je uklonio",
    "An administrator removed you" : "Administrator vas je uklonio",
    "An administrator removed {user}" : "Administrator je uklonio {user}",
    "{actor} added group {group}" : "{actor} je dodao grupu {group}",
    "You added group {group}" : "Dodali ste grupu {group}",
    "An administrator added group {group}" : "Administrator je dodao grupu {group}",
    "{actor} removed group {group}" : "{actor} je uklonio grupu {group}",
    "You removed group {group}" : "Uklonili ste grupu {group}",
    "An administrator removed group {group}" : "Administrator je uklonio grupu {group}",
    "{actor} promoted {user} to moderator" : "{actor} je unaprijedio {user} u moderatora",
    "You promoted {user} to moderator" : "Unaprijedili ste {user} u moderatora",
    "{actor} promoted you to moderator" : "{actor} vas je unaprijedio u moderatora",
    "An administrator promoted you to moderator" : "Administrator vas je unaprijedio u moderatora",
    "An administrator promoted {user} to moderator" : "Administrator je unaprijedio {user} u moderatora",
    "{actor} demoted {user} from moderator" : "{actor} je oduzeo status moderatora {korisnik}",
    "You demoted {user} from moderator" : "Oduzeli ste status moderatora {user}",
    "{actor} demoted you from moderator" : "{actor} vam je oduzeo status moderatora",
    "An administrator demoted you from moderator" : "Administrator vam je oduzeo status moderatora",
    "An administrator demoted {user} from moderator" : "Administrator je oduzeo {user} status moderatora",
    "{actor} shared a file which is no longer available" : "{actor} dijeli datoteku koja više nije dostupna",
    "You shared a file which is no longer available" : "Dijelite datoteku koja više nije dostupna",
    "The shared location is malformed" : "Dijeljena lokacija je pogrešno oblikovana",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} je postavio Matterbridge kako bi sinkronizirao ovaj razgovor s drugim razmjenama poruka",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Postavili ste Matterbridge kako biste sinkronizirali ovaj razgovor s drugim razmjenama poruka",
    "{actor} updated the Matterbridge configuration" : "{actor} je ažurirao konfiguraciju Matterbridgea",
    "You updated the Matterbridge configuration" : "Ažurirali ste konfiguraciju Matterbridgea",
    "{actor} removed the Matterbridge configuration" : "{actor} je uklonio konfiguraciju Matterbridgea",
    "You removed the Matterbridge configuration" : "Uklonili ste konfiguraciju Matterbridgea",
    "{actor} started Matterbridge" : "{actor} je pokrenuo Matterbridge",
    "You started Matterbridge" : "Vi ste pokrenuli Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} je zaustavio Matterbridge",
    "You stopped Matterbridge" : "Vi ste zaustavili Matterbridge",
    "{actor} deleted a message" : "{actor} je izbrisao poruku",
    "You deleted a message" : "Izbrisali ste poruku",
    "{actor} cleared the history of the conversation" : "{actor} je obrisao povijest razgovora",
    "You cleared the history of the conversation" : "Obrisali ste povijest razgovora",
    "Message deleted by author" : "Autor je izbrisao poruku",
    "Message deleted by {actor}" : "Poruku je izbrisao {actor}",
    "Message deleted by you" : "Poruku ste vi izbrisali",
    "Deleted user" : "Izbrisan korisnik",
    "Administration" : "Administracija",
    "System" : "Sustav",
    "%s (guest)" : "%s (gost)",
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} je završio poziv s %n gostom (Trajanje {duration})","{actor} je završio poziv s %n gosta (Trajanje {duration})","{actor} je završio poziv s %n gostiju (Trajanje {duration})"],
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} je završio poziv s {user1} (Trajanje {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} je završio poziv s {user1} i {user2} (Trajanje {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} je završio poziv s {user1}, {user2} i {user3} (Trajanje {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} je završio poziv s {user1}, {user2}, {user3} i {user4} (Trajanje {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} je završio poziv s {user1}, {user2}, {user3}, {user4} i {user5} (Trajanje {duration})",
    "Talk conversations" : "Razgovori u alatu Talk",
    "Talk to %s" : "Razgovarajte s %s",
    "File is not shared, or shared but not with the user" : "Datoteka se ne dijeli ili se ne dijeli samo s korisnikom",
    "No account available to delete." : "Nema računa za brisanje.",
    "No image file provided" : "Nijedna slika nije dobavljena",
    "File is too big" : "Datoteka je prevelika",
    "Invalid file provided" : "Nevažeća datoteka",
    "Invalid image" : "Slika neispravna",
    "Unknown filetype" : "Vrsta datoteke nepoznata",
    "Talk mentions" : "Spominjanja u alatu Talk",
    "Say hi to your friends and colleagues!" : "Pozdravi svoje prijatelje i kolege!",
    "No unread mentions" : "Nema nepročitanih spominjanja",
    "Call in progress" : "Poziv u tijeku",
    "You were mentioned" : "Spomenuti ste",
    "Write to conversation" : "Napiši u razgovor",
    "Writes event information into a conversation of your choice" : "Upisuje informacije o događaju u željeni razgovor",
    "Conversation invitation" : "Poziv u razgovor",
    "Description" : "Opis",
    "You can also dial-in via phone with the following details" : "Također se možete povezati putem telefona sa sljedećim podacima",
    "Dial-in information" : "Podaci za povezivanje putem telefona",
    "Meeting ID" : "ID sastanka",
    "Your PIN" : "Vaš PIN",
    "Password request: %s" : "Zaporka: %s",
    "Private conversation" : "Privatni razgovor",
    "Deleted user (%s)" : "Izbrisan korisnik (%s)",
    "Dismiss notification" : "Zanemari obavijest",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "New message" : "Nova poruka",
    "Reminder" : "Podsjetnik",
    "{user} in {call}" : "{user} u {call}",
    "Deleted user in {call}" : "Izbrisan korisnik u {call}",
    "{guest} (guest) in {call}" : "{guest} (gost) u {call}",
    "Guest in {call}" : "Gost u {call}",
    "{user} sent you a private message" : "{user} vam je poslao privatnu poruku",
    "{user} sent a message in conversation {call}" : "{user} je poslao poruku u razgovoru {call}",
    "A deleted user sent a message in conversation {call}" : "Izbrisani korisnik poslao je poruku u razgovoru {call}",
    "{guest} (guest) sent a message in conversation {call}" : "(gost) {guest} je poslao poruku u razgovoru {call}",
    "A guest sent a message in conversation {call}" : "Gost je poslao poruku u razgovoru {call}",
    "{user} replied to your private message" : "{user} je odgovorio na vašu privatnu poruku",
    "{user} replied to your message in conversation {call}" : "{user} je odgovorio na vašu poruku u razgovoru {call}",
    "A deleted user replied to your message in conversation {call}" : "Izbrisani korisnik odgovorio je na vašu poruku u razgovoru {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "(gost) {guest} je odgovorio na vašu poruku u razgovoru {call}",
    "A guest replied to your message in conversation {call}" : "Gost je odgovorio na vašu poruku u razgovoru {call}",
    "{user} mentioned you in a private conversation" : "{user} vas je spomenuo u privatnom razgovoru",
    "{user} mentioned you in conversation {call}" : "{user} vas je spomenuo u razgovoru {call}",
    "A deleted user mentioned you in conversation {call}" : "Izbrisani korisnik spomenuo vas je u razgovoru {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "(gost) {guest} vas je spomenuo u razgovoru {call}",
    "A guest mentioned you in conversation {call}" : "Gost vas je spomenuo u razgovoru {call}",
    "View chat" : "Prikaži razmjenu poruka",
    "{user} invited you to a group conversation: {call}" : "{user} vas je pozvao u grupni razgovor: {call}",
    "Join call" : "Pridruži se pozivu",
    "Answer call" : "Odgovori na poziv",
    "{user} would like to talk with you" : "{user} želi razgovarati s vama",
    "Call back" : "Nazovi natrag",
    "You missed a call from {user}" : "Propustili ste poziv od {user}",
    "A group call has started in {call}" : "Grupni poziv je pokrenut u {call}",
    "You missed a group call in {call}" : "Propustili ste grupni poziv u {call}",
    "{email} is requesting the password to access {file}" : "{email} traži zaporku za pristup {file}",
    "{email} tried to request the password to access {file}" : "{email} je pokušao zatražiti zaporku za pristup {file}",
    "Someone is requesting the password to access {file}" : "Netko traži zaporku za pristup {file}",
    "Someone tried to request the password to access {file}" : "Netko je pokušao zatražiti zaporku za pristup {file}",
    "Open settings" : "Otvori postavke",
    "The hosted signaling server is now configured and will be used." : "Signalni poslužitelj je konfiguriran i spreman za upotrebu.",
    "The hosted signaling server was removed and will not be used anymore." : "Signalni poslužitelj je uklonjen i neće se upotrebljavati.",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Račun signalnog poslužitelja je promijenio status iz „{oldstatus}” u „{newstatus}”.",
    "error" : "pogreška",
    "Contact via Talk" : "Kontaktirajte putem aplikacije Talk",
    "Open Talk" : "Otvori Talk",
    "Conversations" : "Razgovori",
    "{user}" : "{user}",
    "Messages" : "Poruke",
    "{user} in {conversation}" : "{user} u {conversation}",
    "Messages in other conversations" : "Poruke u ostalim razgovorima",
    "Avatar image is not square" : "Slika avatara nije kvadratna",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Zahtjev za probni rad nije upućen jer probni poslužitelj nije dostupan. Pokušajte ponovo kasnije.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Došlo je do poteškoća s autentifikacijom za ovu instancu. Možda joj nije moguće pristupiti izvana kako bi se provjerio njen URL.",
    "Something unexpected happened." : "Nešto se neočekivano dogodilo.",
    "The URL is invalid." : "URL je nevažeći.",
    "An HTTPS URL is required." : "Potreban je HTTPS URL.",
    "The email address is invalid." : "Nevažeća adresa e-pošte.",
    "The language is invalid." : "Jezik nije valjan.",
    "The country is invalid." : "Nevažeća država.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Došlo je do poteškoća s upućivanjem zahtjeva za probni rad. Provjerite zapisnike za više informacija.",
    "Too many requests are send from your servers address. Please try again later." : "S adrese poslužitelja šalje se previše zahtjeva. Pokušajte ponovo kasnije.",
    "There is already a trial registered for this Nextcloud instance." : "Za ovu instancu Nextclouda već postoji registriran probni račun.",
    "Something unexpected happened. Please try again later." : "Došlo je do neočekivane situacije. Pokušajte ponovo kasnije.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Zahtjev za probni rad nije upućen jer je probni poslužitelj neispravan. Pokušajte ponovo kasnije.",
    "Trial requested but failed to get account information. Please check back later." : "Probni rad je zatražen, ali nisu dohvaćene informacije o računu. Pokušajte kasnije.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Došlo je do poteškoća s autentifikacijom za ovaj zahtjev. Možda joj nije moguće pristupiti izvana kako bi se provjerio njen URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Informacije o računu nisu dohvaćene jer je probni poslužitelj neispravan. Pokušajte ponovo kasnije.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Došlo je do poteškoća s dohvaćanjem informacija o računu. Provjerite zapisnike za više informacija.",
    "There is no such account registered." : "Račun nije registriran.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Informacije o računu nisu dohvaćene jer je probni poslužitelj nedostupan. Pokušajte ponovo kasnije.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Brisanje računa pohranjenog signalnog poslužitelja nije uspjelo. Pokušajte kasnije.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Brisanje računa nije uspjelo jer je probni poslužitelj neispravan. Pokušajte ponovo kasnije.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Došlo je do poteškoća pri brisanju računa. Provjerite zapisnike za više informacija.",
    "Too many requests are sent from your servers address. Please try again later." : "S adrese poslužitelja šalje se previše zahtjeva. Pokušajte ponovo kasnije.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Brisanje računa nije uspjelo jer je probni poslužitelj nedostupan. Pokušajte ponovo kasnije.",
    "Andorra" : "Andora",
    "United Arab Emirates" : "Ujedinjeni Arapski Emirati",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigva i Barbuda",
    "Anguilla" : "Angvila",
    "Albania" : "Albanija",
    "Armenia" : "Armenija",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Argentina",
    "American Samoa" : "Američka Samoa",
    "Austria" : "Austrija",
    "Australia" : "Australija",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ålandski otoci",
    "Azerbaijan" : "Azerbajdžan",
    "Bosnia and Herzegovina" : "Bosna i Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladeš",
    "Belgium" : "Belgija",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bugarska",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Sveti Bartolomej",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunej Darussalam",
    "Bolivia, Plurinational State of" : "Bolivija, Višenacionalna Država",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sveti Eustahije i Saba",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahami",
    "Bhutan" : "Butan",
    "Bouvet Island" : "Otok Bouvet",
    "Botswana" : "Bocvana",
    "Belarus" : "Bjelorusija",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosov (Keeling) otok",
    "Congo, the Democratic Republic of the" : "Kongo, Demokratska Republika",
    "Central African Republic" : "Srednjoafrička Republika",
    "Congo" : "Kongo",
    "Switzerland" : "Švicarska",
    "Côte d'Ivoire" : "Obala Bjelokosti",
    "Cook Islands" : "Cookovo Otočje",
    "Chile" : "Čile",
    "Cameroon" : "Kamerun",
    "China" : "Kina",
    "Colombia" : "Kolumbija",
    "Costa Rica" : "Kostarika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Zelenortska Republika",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Božićni Otok",
    "Cyprus" : "Cipar",
    "Czechia" : "Češka",
    "Germany" : "Njemačka",
    "Djibouti" : "Džibuti",
    "Denmark" : "Danska",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikanska Republika",
    "Algeria" : "Alžir",
    "Ecuador" : "Ekvador",
    "Estonia" : "Estonija",
    "Egypt" : "Egipat",
    "Western Sahara" : "Zapadna Sahara",
    "Eritrea" : "Eritreja",
    "Spain" : "Španjolska",
    "Ethiopia" : "Etiopija",
    "Finland" : "Finska",
    "Fiji" : "Fidži",
    "Falkland Islands (Malvinas)" : "Falklandski otoci (Malvinas)",
    "Micronesia, Federated States of" : "Mikronezija, Federativne Države",
    "Faroe Islands" : "Farski otoci",
    "France" : "Francuska",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Ujedinjeno Kraljevstvo Velike Britanije i Sjeverne Irske",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzija",
    "French Guiana" : "Francuska Gvajana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grenland",
    "Gambia" : "Gambija",
    "Guinea" : "Gvineja",
    "Guadeloupe" : "Gvadalupa",
    "Equatorial Guinea" : "Ekvatorijalna Gvineja",
    "Greece" : "Grčka",
    "South Georgia and the South Sandwich Islands" : "Južna Georgija i otočje Južni Sandwich",
    "Guatemala" : "Gvatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Gvineja Bisau",
    "Guyana" : "Gvajana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Otok Heard i otočje McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Hrvatska",
    "Haiti" : "Haiti",
    "Hungary" : "Mađarska",
    "Indonesia" : "Indonezija",
    "Ireland" : "Irska",
    "Israel" : "Izrael",
    "Isle of Man" : "Otok Man",
    "India" : "Indija",
    "British Indian Ocean Territory" : "Britanski Indijskooceanski teritorij",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Iran, Islamska Republika",
    "Iceland" : "Island",
    "Italy" : "Italija",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenija",
    "Kyrgyzstan" : "Kirgistan",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komori",
    "Saint Kitts and Nevis" : "Sveti Kristofor i Nevis",
    "Korea, Democratic People's Republic of" : "Koreja, Demokratska Narodna Republika",
    "Korea, Republic of" : "Koreja, Republika",
    "Kuwait" : "Kuvajt",
    "Cayman Islands" : "Kajmanski Otoci",
    "Kazakhstan" : "Kazahstan",
    "Lao People's Democratic Republic" : "Laoska Narodna Demokratska Republika",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Sveta Lucija",
    "Liechtenstein" : "Lihtenštajn",
    "Sri Lanka" : "Šri Lanka",
    "Liberia" : "Liberija",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Litva",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Latvija",
    "Libya" : "Libija",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova, Republic of" : "Moldavija, Republika",
    "Montenegro" : "Crna Gora",
    "Saint Martin (French part)" : "Sveti Martin (francuski dio)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Maršalovi Otoci",
    "North Macedonia" : "Sjeverna Makedonija",
    "Mali" : "Mali",
    "Myanmar" : "Mjanmar",
    "Mongolia" : "Mongolija",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Sjevernomarijanski otoci",
    "Martinique" : "Martinik",
    "Mauritania" : "Mauritanija",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauricijus",
    "Maldives" : "Maldivi",
    "Malawi" : "Malavi",
    "Mexico" : "Meksiko",
    "Malaysia" : "Malezija",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibija",
    "New Caledonia" : "Nova Kaledonija",
    "Niger" : "Niger",
    "Norfolk Island" : "Otok Norfolk",
    "Nigeria" : "Nigerija",
    "Nicaragua" : "Nikaragva",
    "Netherlands" : "Nizozemska",
    "Norway" : "Norveška",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Novi Zeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Francuska Polinezija",
    "Papua New Guinea" : "Papua Nova Gvineja",
    "Philippines" : "Filipini",
    "Pakistan" : "Pakistan",
    "Poland" : "Poljska",
    "Saint Pierre and Miquelon" : "Sveti Petar i Mikelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Portoriko",
    "Palestine, State of" : "Palestina, Država",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paragvaj",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Rumunjska",
    "Serbia" : "Srbija",
    "Russian Federation" : "Ruska Federacija",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudijska Arabija",
    "Solomon Islands" : "Salomonski Otoci",
    "Seychelles" : "Sejšeli",
    "Sudan" : "Sudan",
    "Sweden" : "Švedska",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sveta Helena, Ascension i Tristan da Cunha",
    "Slovenia" : "Slovenija",
    "Svalbard and Jan Mayen" : "Svalbard i Jan Mayen",
    "Slovakia" : "Slovačka",
    "Sierra Leone" : "Sijera Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalija",
    "Suriname" : "Surinam",
    "South Sudan" : "Južni Sudan",
    "Sao Tome and Principe" : "Sveti Toma i Princip",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (nizozemski dio)",
    "Syrian Arab Republic" : "Sirijska Arapska Republika",
    "Eswatini" : "Esvatini",
    "Turks and Caicos Islands" : "Otoci Turks i Caicos",
    "Chad" : "Čad",
    "French Southern Territories" : "Francuski južni teritoriji",
    "Togo" : "Togo",
    "Thailand" : "Tajland",
    "Tajikistan" : "Tadžikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Istočni Timor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunis",
    "Tonga" : "Tonga",
    "Turkey" : "Turska",
    "Trinidad and Tobago" : "Trinidad i Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Tajvan, Provincija NR Kine",
    "Tanzania, United Republic of" : "Ujedinjena Republika Tanzanija",
    "Ukraine" : "Ukrajina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Mali udaljeni otoci SAD-a",
    "United States of America" : "Sjedinjene Američke Države",
    "Uruguay" : "Urugvaj",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Sveta Stolica",
    "Saint Vincent and the Grenadines" : "Sveti Vincent i Grenadini",
    "Venezuela, Bolivarian Republic of" : "Venezuela, Bolivarijska Republika",
    "Virgin Islands, British" : "Djevičanski otoci, britanski",
    "Virgin Islands, U.S." : "Djevičanski otoci, SAD",
    "Viet Nam" : "Vijetnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis i Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Južna Afrika",
    "Zambia" : "Zambija",
    "Zimbabwe" : "Zimbabve",
    "Federation" : "Udruženje",
    "High-performance backend" : "Visokoučinkovit pozadinski sustav",
    "Error: Cannot connect to server" : "Pogreška: povezivanje s poslužiteljem nije uspjelo",
    "Error: Server did not respond with proper JSON" : "Pogreška: poslužitelj nije vratio točan JSON",
    "Error: Server responded with: {error}" : "Pogreška: poslužitelj je vratio: {error}",
    "Error: Unknown error occurred" : "Pogreška: došlo je do nepoznate pogreške",
    "SIP configuration" : "Konfiguracija SIP-a",
    "Invalid date, date format must be YYYY-MM-DD" : "Nevažeći datum, oblik datuma mora biti GGGG-MM-DD",
    "Conversation not found" : "Razgovor nije pronađen",
    "Chat, video & audio-conferencing using WebRTC" : "Razmjena poruka, videopozivi i glasovne konferencije putem WebRTC-a",
    "Leave call" : "Napusti poziv",
    "Navigating away from the page will leave the call in {conversation}" : "Zatvaranjem stranice napustit ćete poziv u {conversation}",
    "Stay in call" : "Ostani u pozivu",
    "Discuss this file" : "Raspravi o ovoj datoteci",
    "Share this file with others to discuss it" : "Podijeli ovu datoteku s drugima radi rasprave",
    "Share this file" : "Dijeli ovu datoteku",
    "Join conversation" : "Pridruži se razgovoru",
    "Request password" : "Zatraži zaporku",
    "Error requesting the password." : "Pogreška pri traženju zaporke.",
    "This conversation has ended" : "Ovaj je razgovor završio",
    "Everyone" : "Svi",
    "Users and moderators" : "Korisnici i moderatori",
    "Moderators only" : "Samo moderatori",
    "Save changes" : "Spremi promjene",
    "Saving …" : "Spremanje...",
    "Saved!" : "Spremljeno!",
    "Limit to groups" : "Ograniči na grupe",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Kada je odabrana barem jedna grupa, samo članovi navedenih grupa mogu sudjelovati u razgovorima.",
    "Guests can still join public conversations." : "Gosti se i dalje mogu pridružiti javnim razgovorima.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Korisnici koji više ne mogu upotrebljavati aplikaciju Talk i dalje će biti navedeni kao sudionici u svojim završenim razgovorima i čuvat će se njihove razmijenjene poruke.",
    "Limit using Talk" : "Ograniči korištenje aplikacije Talk",
    "Limit creating a public and group conversation" : "Ograniči stvaranje javnih i grupnih razgovora",
    "Limit creating conversations" : "Ograniči stvaranje razgovora",
    "Limit starting a call" : "Ograniči upućivanje poziva",
    "Limit starting calls" : "Ograniči upućivanje poziva",
    "When a call has started, everyone with access to the conversation can join the call." : "Nakon uspostavljanja, pozivu se može pridružiti svatko kome je odobren pristup razgovoru.",
    "Enabled" : "Omogućeno",
    "Disabled" : "Onemogućeno",
    "State" : "Stanje",
    "Name" : "Naziv",
    "Beta" : "Beta",
    "Permissions" : "Dopuštenja",
    "All messages" : "Sve poruke",
    "@-mentions only" : "Samo @-spominjanja",
    "Off" : "Isključeno",
    "General settings" : "Opće postavke",
    "Default notification settings" : "Zadane postavke obavijesti",
    "Default group notification" : "Zadane obavijesti grupe",
    "Default group notification for new groups" : "Zadane obavijesti grupe za nove grupe",
    "Integration into other apps" : "Integracija s drugim aplikacijama",
    "Allow conversations on files" : "Dopusti razgovore na datotekama",
    "Allow conversations on public shares for files" : "Dopusti razgovore na javnim dijeljenjima za datoteke",
    "Enable encryption" : "Omogući šifriranje",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Informacije iz obrasca poslat će se tvrtki Struktur AG ako kliknete na gumb iznad. Više informacija možete pronaći na {linkstart}spreed.eu{linkend}.",
    "Pending" : "Na čekanju",
    "Error" : "Pogreška",
    "Blocked" : "Blokiran",
    "Active" : "Aktivan",
    "Expired" : "Istekao",
    "The trial could not be requested. Please try again later." : "Nije moguće zatražiti probni rad. Pokušajte ponovo kasnije.",
    "The account could not be deleted. Please try again later." : "Nije moguće izbrisati račun. Pokušajte ponovo kasnije.",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Naš partner Struktur AG pruža uslugu putem koje možete zatražiti signalni poslužitelj. Trebate ispuniti obrazac u nastavku i vaš će Nextcloud zatražiti signalni poslužitelj. Vjerodajnice se automatski popunjavaju nakon postavljanja poslužitelja. Time ćete prebrisati postavke postojećeg signalnog poslužitelja.",
    "URL of this Nextcloud instance" : "URL ove instance Nextclouda",
    "Full name of the user requesting the trial" : "Puno ime korisnika koji je zatražio probu",
    "Email of the user" : "Adresa e-pošte korisnika",
    "Language" : "Jezik",
    "Country" : "Država",
    "Request signaling server trial" : "Zatraži probu signalnog poslužitelja",
    "You can see the current status of your hosted signaling server in the following table." : "Trenutni status signalnog poslužitelja možete pronaći u sljedećoj tablici.",
    "Status" : "Status",
    "Created at" : "Stvoreno",
    "Expires at" : "Istječe u",
    "Limits" : "Ograničenja",
    "Delete the signaling server account" : "Brisanje računa signalnog poslužitelja",
    "_%n user_::_%n users_" : ["%n korisnik","%n korisnika","%n korisnika"],
    "Installed version: {version}" : "Instalirana inačica: {version}",
    "Matterbridge binary was not found or couldn't be executed." : "Binarna datoteka Matterbridge nije pronađena ili se ne može izvršiti.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Put do binarnog programa Matterbridge također možete ručno postaviti u samoj konfiguraciji. Dodatne informacije potražite u {linkstart}dokumentaciji za integraciju Matterbridgea{linkend}.",
    "Downloading …" : "Preuzimanje…",
    "Install Talk Matterbridge" : "Instalirajte Talk Matterbridge",
    "Failed to execute Matterbridge binary." : "Izvršavanje binarne datoteke Matterbridge nije uspjelo.",
    "Matterbridge integration" : "Matterbridge integracija",
    "Enable Matterbridge integration" : "Omogućite Matterbridge integraciju",
    "Status: Checking connection" : "Status: provjeravanje veze",
    "OK: Running version: {version}" : "U redu: trenutna inačica: {version}",
    "Validate SSL certificate" : "Potvrdi vjerodajnicu SSL-a",
    "Delete this server" : "Izbriši ovaj poslužitelj",
    "Test this server" : "Ispitaj ovaj poslužitelj",
    "Shared secret" : "Dijeljen tajni ključ",
    "Restrict SIP configuration" : "Ograniči konfiguraciju SIP-a",
    "Enable SIP configuration" : "Omogući konfiguraciju SIP-a",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Samo korisnici iz sljedećih grupa mogu omogućiti SIP u razgovorima koje moderiraju",
    "Phone number (Country)" : "Broj telefona (država)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Ove se informacije šalju u porukama e-pošte s pozivnicama i prikazuju se u bočnoj traci sudionika.",
    "High-performance backend URL" : "URL visokoučinkovitog pozadinskog sustava",
    "STUN server URL" : "URL poslužitelja STUN",
    "STUN servers" : "Poslužitelji STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Poslužitelj STUN upotrebljava se za određivanje javne IP adrese sudionika iza usmjerivača.",
    "{schema} scheme must be used with a domain" : "Shema {schema} mora se upotrebljavati s domenom",
    "{option1} and {option2}" : "{option1} i {option2}",
    "{option} only" : "Samo {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "U redu: poslužitelj TURN vratio je uspješne ICE kandidate",
    "Error: No working ICE candidates returned by the TURN server" : "Pogreška: poslužitelj TURN nije vratio ispravne ICE kandidate",
    "Testing whether the TURN server returns ICE candidates" : "Ispitivanje hoće li poslužitelj TURN vratiti ICE kandidate",
    "TURN server schemes" : "Sheme poslužitelja TURN",
    "TURN server URL" : "URL poslužitelja TURN",
    "TURN server secret" : "Tajni ključ poslužitelja TURN",
    "TURN server protocols" : "Protokoli poslužitelja TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Poslužitelj TURN upotrebljava se za usmjeravanje prometa sudionika iza vatrozida. Ako se pojedini sudionici ne mogu povezati s drugim sudionicima, vjerojatno je potreban poslužitelj TURN. Upute za postavljanje poslužitelja možete pronaći u {linkstart}ovoj dokumentaciji{linkend}.",
    "TURN servers" : "Poslužitelji TURN",
    "OK" : "U redu",
    "Confirm" : "Potvrdi",
    "Reset" : "Resetiraj",
    "Back" : "Natrag",
    "Cancel" : "Odustani",
    "Add participant \"{user}\"" : "Dodaj sudionika „{user}”",
    "Loading …" : "Učitavanje…",
    "From" : "Od",
    "To" : "Do",
    "Calendar" : "Kalendar",
    "Attendees" : "Sudionici",
    "Save" : "Spremi",
    "Search participants" : "Pretraži sudionike",
    "No results" : "Nema rezultata",
    "Raise hand" : "Podigni ruku",
    "Raise hand (R)" : "Podigni ruku (R)",
    "Lower hand" : "Spusti ruku",
    "Lower hand (R)" : "Spusti ruku (R)",
    "Speaker view" : "Prikaz govornika",
    "Grid view" : "Prikaz rešetke",
    "This conversation is read-only" : "Ovaj razgovor je samo za čitanje",
    "{nickName} raised their hand." : "{nickName} je podigao ruku.",
    "A participant raised their hand." : "Sudionik je podigao ruku.",
    "Collapse stripe" : "Sakrij traku",
    "Expand stripe" : "Proširi traku",
    "Previous page of videos" : "Prethodna stranica s videozapisima",
    "Next page of videos" : "Sljedeća stranica s videozapisima",
    "Connecting …" : "Povezivanje…",
    "Waiting for others to join the call …" : "Čekaju se drugi sudionici da se pridruže pozivu...",
    "You can invite others in the participant tab of the sidebar" : "Druge sudionike možete pozvati putem kartice sudionika na bočnoj traci",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Druge sudionike možete pozvati putem kartice sudionika na bočnoj traci ili slanjem ove poveznice!",
    "Share this link to invite others!" : "Podijelite ovu poveznicu kako biste pozvali ostale sudionike!",
    "Copy link" : "Kopiraj poveznicu",
    "You are not allowed to enable audio" : "Nije vam dopušteno omogućiti zvuk",
    "Mute audio" : "Isključi zvuk",
    "Mute audio (M)" : "Isključi zvuk (M)",
    "Unmute audio" : "Uključi zvuk",
    "Unmute audio (M)" : "Uključi zvuk (M)",
    "None" : "Nema",
    "Access to camera was denied" : "Pristup kameri je odbijen",
    "Error while accessing camera" : "Došlo je do pogreške pri pristupanju kameri",
    "You have been muted by a moderator" : "Utišao vas je moderator",
    "You are not allowed to enable video" : "Nije vam dopušteno omogućiti videoprijenos",
    "Disable video" : "Onemogući videoprijenos",
    "Disable video (V)" : "Onemogući videoprijenos (V)",
    "Enable video" : "Omogući videoprijenos",
    "Enable video (V)" : "Omogući videoprijenos (V)",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Omogući videoprijenos (V) – veza će se nakratko prekinuti pri prvom omogućivanju videoprijenosa",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Omogući videoprijenos. Veza će se nakratko prekinuti pri prvom omogućivanju videoprijenosa",
    "You" : "Vi",
    "Mute" : "Utišaj",
    "Show screen" : "Prikaži zaslon",
    "Stop following" : "Prekini praćenje",
    "Collapse" : "Sakrij",
    "You need to be logged in to upload files" : "Morate biti prijavljeni kako biste otpremali datoteke",
    "Drop your files to upload" : "Ispustite datoteke za otpremu",
    "Conversation messages" : "Poruke razgovora",
    "Scroll to bottom" : "Pomakni se na dno",
    "Post message" : "Objavi poruku",
    "Favorite" : "Favorit",
    "Date:" : "Datum:",
    "Hide details" : "Sakrij pojedinosti",
    "Show details" : "Prikaži pojedinosti",
    "Error while updating conversation description" : "Pogreška pri ažuriranju opisa razgovora",
    "Edit conversation description" : "Opis uređivanja razgovora",
    "Enter a description for this conversation" : "Unesite opis ovog razgovora",
    "Disable" : "Onemogući",
    "Enable" : "Omogućite",
    "Choose" : "Odaberite",
    "Default permissions modified for {conversationName}" : "Izmijenjena su zadana dopuštenja za {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Nije moguće izmijeniti zadana dopuštenja za {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Uredite zadana dopuštenja za sudionike ovog razgovora. Ove postavke ne utječu na moderatore.",
    "All permissions" : "Sva dopuštenja",
    "Restricted" : "Ograničeno",
    "Advanced permissions" : "Napredna dopuštenja",
    "Edit permissions" : "Uredi dopuštenja",
    "Meeting" : "Sastanak",
    "Conversation settings" : "Postavke razgovora",
    "Personal" : "Osobno",
    "Matterbridge" : "Matterbridge",
    "Danger zone" : "Zona opasnosti",
    "Do you really want to delete \"{displayName}\"?" : "Želite li zaista izbrisati „{displayName}“?",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Želite li zaista izbrisati sve poruke u „{displayName}“?",
    "Error while deleting conversation" : "Pogreška pri brisanju razgovora",
    "Error while clearing chat history" : "Pogreška pri brisanju povijesti razmjene poruka",
    "Be careful, these actions cannot be undone." : "Pažljivo nastavite jer ove radnje nije moguće poništiti.",
    "Leave conversation" : "Napusti razgovor",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Nakon izlaska iz razgovora za ponovni pristup zatvorenom razgovoru potreban je poziv. Otvorenom razgovoru možete se ponovno pridružiti u bilo kojem trenutku.",
    "No" : "Ne",
    "Yes" : "Da",
    "Delete conversation" : "Izbriši razgovor",
    "Permanently delete this conversation." : "Trajno izbrišite ovaj razgovor.",
    "Delete chat messages" : "Izbriši razmijenjene poruke",
    "Permanently delete all the messages in this conversation." : "Trajno izbrišite sve poruke u ovom razgovoru.",
    "Delete all chat messages" : "Izbriši sve razmijenjene poruke",
    "Password protection" : "Zaštita zaporkom",
    "Set a password" : "Postavi zaporku",
    "Save password" : "Spremi zaporku",
    "Resend invitations" : "Ponovno pošalji pozivnice",
    "Error occurred when opening or limiting the conversation" : "Došlo je do pogreške pri otvaranju ili ograničavanju razgovora",
    "Start time has been updated" : "Vrijeme početka je ažurirano",
    "Error occurred while updating start time" : "Došlo je do pogreške pri ažuriranju vremena početka",
    "Meeting start time" : "Vrijeme početka sastanka",
    "Start time (optional)" : "Vrijeme početka (neobvezno)",
    "Error occurred when locking the conversation" : "Došlo je do pogreške pri zaključavanju razgovora",
    "Error occurred when unlocking the conversation" : "Došlo je do pogreške pri otključavanju razgovora",
    "Lock conversation" : "Zaključaj razgovor",
    "This will also terminate the ongoing call." : "Ovime ćete također prekinuti poziv.",
    "Edit" : "Uredi",
    "More information" : "Više informacija",
    "Delete" : "Izbriši",
    "Add new bridged channel to current conversation" : "Dodaj novi povezani kanal u trenutačni razgovor",
    "unknown state" : "nepoznato stanje",
    "running" : "radi",
    "not running, check Matterbridge log" : "nije pokrenuto, provjeri zapisnik Matterbridgea",
    "not running" : "ne radi",
    "Bridge saved" : "Veza spašena",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Zahvaljujući aplikaciji Matterbridge možete povezati kanale iz različitih sustava razmjene kratkih poruka.",
    "More info on Matterbridge" : "Više informacija o Matterbridgeu",
    "Enable bridge" : "Omogući povezivanje",
    "Show Matterbridge log" : "Prikaži zapisnik Matterbridgea",
    "Log content" : "Sadržaj zapisa",
    "Notifications" : "Obavijesti",
    "Notify about calls in this conversation" : "Obavijesti o pozivima u ovom razgovoru",
    "Important conversation" : "Važan razgovor",
    "SIP dial-in is now enabled" : "Povezivanje putem SIP-a je omogućeno",
    "SIP dial-in is now disabled" : "Povezivanje putem SIP-a je onemogućeno",
    "Error occurred when enabling SIP dial-in" : "Došlo je do pogreške pri omogućavanju povezivanja putem SIP-a",
    "Error occurred when disabling SIP dial-in" : "Došlo je do pogreške pri onemogućavanju povezivanja putem SIP-a",
    "Join" : "Pridruži se",
    "Error while creating the conversation" : "Pogreška pri stvaranju razgovora",
    "Unread mentions" : "Nepročitana spominjanja",
    "Create conversation" : "Stvori razgovor",
    "Enter your name" : "Unesite svoje ime",
    "Log in" : "Prijavite se",
    "Mark as read" : "Označi kao pročitano",
    "Mark as unread" : "Označi kao nepročitano",
    "Remove from favorites" : "Ukloni iz favorita",
    "Add to favorites" : "Dodaj u favorite",
    "You need to promote a new moderator before you can leave the conversation." : "Morate odabrati novog moderatora prije nego što napustite razgovor.",
    "Conversation actions" : "Radnje razgovora",
    "No matches found" : "Nema pronađenih podudaranja",
    "No conversations found" : "Nije pronađen nijedan razgovor",
    "An error occurred while performing the search" : "Došlo je do pogreške pri pretraživanju",
    "Conversation list" : "Popis razgovora",
    "Unread messages" : "Nepročitane poruke",
    "Clear filter" : "Ukloni filtar",
    "Talk settings" : "Postavke razgovora",
    "Users" : "Korisnici",
    "Groups" : "Grupe",
    "Open conversations" : "Otvori razgovore",
    "No search results" : "Nema rezultata pretraživanja",
    "Users and groups" : "Korisnici i grupe",
    "Other sources" : "Drugi izvori",
    "The meeting will start soon" : "Sastanak počinje uskoro",
    "This meeting is scheduled for {startTime}" : "Sastanak počinje u {startTime}",
    "You are currently waiting in the lobby" : "Trenutno čekate u predvorju",
    "Select microphone" : "Odaberi mikrofon",
    "No microphone available" : "Nema dostupnih mikrofona",
    "Select camera" : "Odaberi kameru",
    "No camera available" : "Nema dostupnih kamera",
    "Test" : "Ispitivanje",
    "Devices" : "Uređaji",
    "No audio" : "Nema zvuka",
    "No camera" : "Nema kamere",
    "Calls are not supported in your browser" : "Vaš preglednik ne podržava pozive",
    "Access to microphone is only possible with HTTPS" : "Pristup mikrofonu moguć je samo putem HTTPS-a",
    "Access to microphone was denied" : "Pristup mikrofonu je odbijen",
    "Error while accessing microphone" : "Došlo je do pogreške pri pristupanju mikrofonu",
    "Access to camera is only possible with HTTPS" : "Pristup kameri moguć je samo putem HTTPS-a",
    "Invalid path selected" : "Odabran nevažeći put",
    "Upload" : "Otpremi",
    "Files" : "Datoteke",
    "Message read by everyone who shares their reading status" : "Poruku je pročitao svatko tko dijeli status čitanja",
    "Message sent" : "Poruka poslana",
    "Deleting message" : "Brisanje poruke",
    "Message deleted successfully" : "Poruka je uspješno izbrisana",
    "Message could not be deleted because it is too old" : "Poruku nije moguće izbrisati jer je prestara",
    "Only normal chat messages can be deleted" : "Mogu se izbrisati samo uobičajene razmijenjene poruke",
    "An error occurred while deleting the message" : "Došlo je do pogreške pri brisanju poruke",
    "Reply" : "Odgovori",
    "Reply privately" : "Odgovori privatno",
    "Copy message link" : "Kopiraj poveznicu poruke",
    "Go to file" : "Idi na datoteku",
    "Forward message" : "Proslijedi poruku",
    "Translate" : "Prevedi",
    "Choose a conversation to forward the selected message." : "Odaberite razgovor u koji ćete proslijediti odabranu poruku.",
    "Error while forwarding message" : "Pogreška pri prosljeđivanju poruke",
    "The message has been forwarded to {selectedConversationName}" : "Poruka je proslijeđena u {selectedConversationName}",
    "Dismiss" : "Zanemari",
    "Go to conversation" : "Idi na razgovor",
    "Your browser does not support playing audio files" : "Vaš preglednik ne podržava reprodukciju zvučnih datoteka",
    "Contact" : "Kontakt",
    "{stack} in {board}" : "{stack} u {board}",
    "Deck Card" : "Deck kartica",
    "Remove {fileName}" : "Ukloni {fileName}",
    "Open this location in OpenStreetMap" : "Otvorite ovu lokaciju u aplikaciji OpenStreetMap",
    "Sending message" : "Slanje poruke",
    "Failed to send the message. Click to try again" : "Slanje poruke nije uspjelo. Kliknite kako biste ponovno pokušali",
    "Not enough free space to upload file" : "Nema dovoljno slobodnog prostora za otpremanje datoteke",
    "You are not allowed to share files" : "Nije vam dopušteno dijeliti datoteke",
    "You cannot send messages to this conversation at the moment" : "Trenutno ne možete slati poruke u ovaj razgovor",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "_%n day ago_::_%n days ago_" : ["Prije %n dana","Prije %n dana","Prije %n dana"],
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "No messages" : "Nema poruka",
    "Create a new group conversation" : "Stvori novi grupni razgovor",
    "Add participants" : "Dodaj sudionike",
    "Allow guests to join via link" : "Dopusti pridruživanje gostiju putem pozivnice",
    "Enter password" : "Unesi zaporku",
    "This conversation has been locked" : "Ovaj je razgovor zaključan",
    "No permission to post messages in this conversation" : "Nije dopušteno objavljivanje poruka u ovom razgovoru",
    "Joining conversation …" : "Pridruživanje razgovoru...",
    "Send message" : "Pošalji poruku",
    "File to share" : "Datoteka za dijeljenje",
    "Add emoji" : "Dodaj emoji",
    "Share from Files" : "Dijeli iz datoteka",
    "Share files to the conversation" : "Dijeli datoteke u razgovor",
    "Create new poll" : "Stvori novu anketu",
    "Record voice message" : "Snimi glasovnu poruku",
    "End recording and send" : "Završi snimak i pošalji",
    "Dismiss recording" : "Odbaci snimak",
    "Access to the microphone was denied" : "Pristup mikrofonu je odbijen",
    "Microphone either not available or disabled in settings" : "Mikrofon nije raspoloživ ili je onemogućen u postavkama",
    "Error while recording audio" : "Pogreška tijekom snimanja zvuka",
    "Talk recording from {time} ({conversation})" : "Snimak iz aplikacije Talk od {time} ({conversation})",
    "New file" : "Nova datoteka",
    "Blank" : "Prazno",
    "Add more files" : "Dodaj više datoteka",
    "Send" : "Pošalji",
    "In this conversation <strong>{user}</strong> can:" : "U ovom razgovoru <strong>{user}</strong> može:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Uredite zadana dopuštenja za sudionike u <strong>{conversationName}</strong>",
    "Start a call" : "Uputi poziv",
    "Skip the lobby" : "Preskoči predvorje",
    "Enable the microphone" : "Omogućite mikrofon",
    "Enable the camera" : "Omogućite kameru",
    "Share the screen" : "Dijelite zaslon",
    "Update permissions" : "Ažuriraj dopuštenja",
    "Updating permissions" : "Ažuriranje dopuštenja",
    "Settings" : "Postavke",
    "Anonymous poll" : "Anonimna anketa",
    "Disable lobby" : "Onemogući predvorje",
    "Settings for participant \"{user}\"" : "Postavke sudionika „{user}”",
    "Participant \"{user}\"" : "Sudionik „{user}”",
    "moderator" : "moderator",
    "bot" : "bot",
    "guest" : "gost",
    "Raised their hand" : "Podigli ruke",
    "Joined with video" : "Pridružen putem videoveze",
    "Joined via phone" : "Pridružen putem telefona",
    "Joined with audio" : "Pridružen putem audioveze",
    "Remove group and members" : "Ukloni grupu i članove",
    "Remove participant" : "Ukloni sudionika",
    "Permissions granted to {displayName}" : "Dopuštenja dodijeljena {displayName}",
    "Could not modify permissions for {displayName}" : "Nije moguće izmijeniti dopuštenja za {displayName}",
    "Permissions removed for {displayName}" : "Uklonjena su dopuštenja za {displayName}",
    "Dial-in PIN" : "PIN za povezivanje putem telefona",
    "Demote from moderator" : "Ukloni moderatora",
    "Promote to moderator" : "Unaprijedi u moderatora",
    "Resend invitation" : "Ponovno pošalji pozivnicu",
    "Grant all permissions" : "Dodijeli sva dopuštenja",
    "Remove all permissions" : "Ukloni sva dopuštenja",
    "Remove" : "Ukloni",
    "Permissions modified for {displayName}" : "Izmijenjena su dopuštenja za {displayName}",
    "Add users or groups" : "Dodaj korisnike ili grupe",
    "Add users" : "Dodaj korisnike",
    "Add groups" : "Dodaj grupe",
    "Add other sources" : "Dodaj druge izvore",
    "Add emails" : "Dodaj adrese e-pošte",
    "Integrations" : "Integracije",
    "Searching …" : "Traženje…",
    "Search for more users" : "Potraži još korisnika",
    "Search or add participants" : "Traži ili dodaj sudionike",
    "An error occurred while adding the participants" : "Došlo je do pogreške pri dodavanju sudionika",
    "Participants" : "Sudionici",
    "Participants ({count})" : "Sudionici ({count})",
    "Open chat" : "Otvori prozor za razmjenu poruka",
    "You have new unread messages in the chat." : "Imate nove nepročitane poruke u prozoru za razmjenu poruka.",
    "You have been mentioned in the chat." : "Spomenuti ste u razmijenjenim porukama.",
    "Chat" : "Razmjena poruka",
    "Details" : "Pojedinosti",
    "No results found" : "Nema rezultata",
    "Load more results" : "Učitaj više rezultata",
    "Projects" : "Projekti",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Poveznica za sudjelovanje u razgovoru",
    "Search conversations or users" : "Pretraži razgovore ili korisnike",
    "Select conversation" : "Odaberi razgovor",
    "Choose the folder in which attachments should be saved." : "Odaberite mapu za spremanje privitaka.",
    "Select location for attachments" : "Odaberite lokaciju privitaka",
    "Error while setting attachment folder" : "Pogreška pri postavljanju mape za privitke",
    "Your privacy setting has been saved" : "Postavka privatnosti je spremljena",
    "Error while setting read status privacy" : "Pogreška pri postavljanju privatnosti statusa čitanja",
    "Failed to save sounds setting" : "Spremanje postavki zvukova nije uspjelo",
    "Sounds setting saved" : "Postavka zvukova je spremljena",
    "Error while saving sounds setting" : "Pogreška pri spremanju postavke zvukova",
    "Attachments folder" : "Mapa s privicima",
    "Appearance" : "Izgled",
    "Privacy" : "Privatnost",
    "Share my read-status and show the read-status of others" : "Dijeli moj status čitanja i prikaži statuse čitanja drugih sudionika",
    "Sounds" : "Zvuci",
    "Play sounds when participants join or leave a call" : "Reproduciraj zvukove kad se sudionici pridruže ili napuste poziv",
    "Performance" : "Učinkovitost",
    "Keyboard shortcuts" : "Tipkovni prečaci",
    "Speed up your Talk experience with these quick shortcuts." : "Ubrzajte korištenje aplikacije Talk s pomoću ovih brzih prečaca.",
    "Focus the chat input" : "Fokusirajte ulazne poruke",
    "Unfocus the chat input to use shortcuts" : "Odfokusirajte ulazne poruke kako biste iskoristili prečace",
    "Fullscreen the chat or call" : "Razmjena poruka ili poziv preko cijelog zaslona",
    "Search" : "Traži",
    "Shortcuts while in a call" : "Prečaci tijekom poziva",
    "Microphone on and off" : "Mikrofon uključen i isključen",
    "Space bar" : "Razmaknica",
    "Push to talk or push to mute" : "Pritisni za govor ili pritisni za utišavanje",
    "Raise or lower hand" : "Podigni ili spusti ruku",
    "More actions" : "Dodatne radnje",
    "Start call" : "Uputi poziv",
    "You will be able to join the call only after a moderator starts it." : "Pozivu ćete se moći pridružiti tek nakon što ga moderator pokrene.",
    "Recording" : "Snimanje",
    "Default" : "Zadano",
    "You are not allowed to enable screensharing" : "Nije vam dopušteno omogućiti dijeljenje zaslona",
    "No screensharing" : "Nema dijeljenja zaslona",
    "Screensharing options" : "Mogućnosti dijeljenja zaslona",
    "Enable screensharing" : "Omogući dijeljenje zaslona",
    "Bad sent video and screen quality." : "Nekvalitetan videozapis i prikaz.",
    "Bad sent screen quality." : "Nekvalitetan prikaz.",
    "Bad sent video quality." : "Nekvalitetan videozapis.",
    "Bad sent audio, video and screen quality." : "Nekvalitetan audiozapis, videozapis i prikaz.",
    "Bad sent audio and screen quality." : "Nekvalitetan audiozapis i prikaz.",
    "Bad sent audio and video quality." : "Nekvalitetan audiozapis i videozapis.",
    "Bad sent audio quality." : "Nekvalitetan audiozapis.",
    "Disable background blur" : "Onemogući zamućenje pozadine",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Vaša internetska veza ili računalo je zauzeto pa drugi sudionici možda neće vidjeti vaš zaslon. Kako biste otklonili poteškoće, pokušajte onemogućiti prijenos videozapisa dok dijelite zaslon.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Vaša internetska veza ili računalo je zauzeto pa drugi sudionici možda neće vidjeti vaš zaslon.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti i razumjeti. Kako biste otklonili poteškoće, pokušajte onemogućiti zamućenje pozadine ili prijenos videozapisa dok dijelite zaslon.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti i razumjeti. Kako biste otklonili poteškoće, pokušajte onemogućiti prijenos videozapisa dok dijelite zaslon.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti i razumjeti niti vidjeti vaš zaslon. Kako biste otklonili poteškoće, pokušajte onemogućiti dijeljenje zaslona.",
    "Disable screenshare" : "Onemogući dijeljenje zaslona",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti i razumjeti. Kako biste otklonili poteškoće, pokušajte onemogućiti zamućenje pozadine ili prijenos videozapisa.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti i razumjeti. Kako biste otklonili poteškoće, pokušajte onemogućiti prijenos videozapisa.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće razumjeti.",
    "Screen sharing is not supported by your browser." : "Vaš preglednik ne podržava dijeljenje zaslona.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Dijeljenje zaslona zahtijeva učitavanje stranice putem HTTPS-a.",
    "Screensharing requires the page to be loaded through HTTPS." : "Dijeljenje zaslona zahtijeva učitavanje stranice putem HTTPS-a.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Dijeljenje zaslona moguće je samo u pregledniku Firefox, inačice 52 ili novije.",
    "Screensharing extension is required to share your screen." : "Za dijeljenje zaslona potrebno je instalirati proširenje za dijeljenje zaslona.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Koristite se nekim drugim preglednikom za dijeljenje zaslona, primjerice preglednikom Firefox ili Chrome.",
    "An error occurred while starting screensharing." : "Došlo je do pogreške pri pokretanju dijeljenja zaslona.",
    "Show your screen" : "Pokaži svoj zaslon",
    "Stop screensharing" : "Prekini dijeljenje zaslona",
    "Mute others" : "Utišaj druge",
    "Select a region" : "Odaberite regiju",
    "Submit" : "Šalji",
    "Search …" : "Traži …",
    "Message without mention" : "Poruka bez spominjanja",
    "Mention myself" : "Spomeni sebe",
    "The conversation does not exist" : "Razgovor ne postoji",
    "Join a conversation or start a new one!" : "Pridružite se razgovoru ili započnite novi!",
    "Duplicate session" : "Udvostruči sesiju",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Pridružili ste se razgovoru u drugom prozoru ili na drugom uređaju. Nextcloud Talk trenutačno ne podržava tu radnju pa je ova sesija zatvorena.",
    "Join a conversation or start a new one" : "Pridružite se razgovoru ili započnite novi",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud korisnik",
    "User password" : "Korisnička lozinka",
    "Talk conversation" : "Razgovori u alatu Talk",
    "Skip TLS verification" : "Preskoči TLS provjeru",
    "Matrix server URL" : "URL poslužitelja Matrix",
    "User" : "Korisnik",
    "Matrix channel" : "Matrix kanal",
    "Mattermost server URL" : "URL poslužitelja Mattermost",
    "Mattermost user" : "Mattermost korisnik",
    "Team name" : "Naziv tima",
    "Channel name" : "Naziv kanala",
    "Rocket.Chat server URL" : "URL poslužitelja Rocket.Chat",
    "User name or email address" : "Korisničko ime ili adresa e-pošte",
    "Password" : "Zaporka",
    "Rocket.Chat channel" : "Rocket.Chat kanal",
    "Zulip server URL" : "URL poslužitelja Zulip",
    "Bot user name" : "Korisničko ime Bota",
    "Bot API key" : "Ključ API-ja Bot",
    "Zulip channel" : "Zulip kanal",
    "API token" : "API token",
    "Slack channel" : "Slack kanal",
    "Server ID or name" : "ID ili naziv poslužitelja",
    "Channel" : "Kanal",
    "Login" : "Prijava",
    "Chat ID" : "ID alata za razmjenu poruka",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL IRC poslužitelja (npr. chat.freenode.net:6667)",
    "Nickname" : "Nadimak",
    "Connection password" : "Lozinka veze",
    "IRC channel" : "IRC kanal",
    "Channel password" : "Lozinka za kanal",
    "NickServ nickname" : "NickServ nadimak",
    "NickServ password" : "NickServ lozinka",
    "Use TLS" : "Koristi TLS",
    "Use SASL" : "Koristi SASL",
    "Tenant ID" : "ID stanara",
    "Client ID" : "ID klijenta",
    "Team ID" : "ID tima",
    "Thread ID" : "ID dretve",
    "XMPP/Jabber server URL" : "URL poslužitelja XMPP/Jabber",
    "MUC server URL" : "URL poslužitelja MUC",
    "Jabber ID" : "ID Jabbera",
    "Media" : "Medij",
    "Polls" : "Ankete",
    "Locations" : "Lokacije",
    "Audio" : "Audio",
    "Other" : "Drugo",
    "Show all files" : "Prikaži sve datoteke",
    "Group" : "Grupa",
    "You: {lastMessage}" : "Vi: {lastMessage}",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Pokušavate se pridružiti razgovoru dok imate otvorenu sesiju u drugom prozoru ili na drugom uređaju. Nextcloud Talk trenutačno ne podržava tu radnju. Što želite učiniti?",
    "Leave this page" : "Napusti ovu stranicu",
    "Join here" : "Pridruži se ovdje",
    "Post to a conversation" : "Objavite u razgovoru",
    "Post to conversation" : "Objavi u razgovoru",
    "Error while clearing conversation history" : "Pogreška pri brisanju povijesti razgovora",
    "Error occurred while allowing guests" : "Došlo je do pogreške pri omogućavanju pristupa gostima",
    "Error occurred while disallowing guests" : "Došlo je do pogreške pri onemogućavanju pristupa gostima",
    "Error occurred when restricting the conversation to moderator" : "Došlo je do pogreške pri ograničavanju razgovora samo na moderatore",
    "Error occurred when opening the conversation to everyone" : "Došlo je do pogreške pri otvaranju razgovora svima",
    "Conversation password has been saved" : "Zaporka razgovora je spremljena",
    "Conversation password has been removed" : "Zaporka razgovora je uklonjena",
    "Error occurred while saving conversation password" : "Došlo je do pogreške pri spremanju zaporke razgovora",
    "Error while uploading file \"{fileName}\"" : "Pogreška pri otpremanju datoteke „{fileName}”",
    "Not enough free space to upload file \"{fileName}\"" : "Nema dovoljno slobodnog prostora za otpremanje datoteke „{fileName}”",
    "Error while sharing file" : "Pogreška pri dijeljenju datoteke",
    "Could not post message: {errorMessage}" : "Nije moguće objaviti poruku: {errorMessage}",
    "An error occurred while fetching the participants" : "Došlo je do pogreške pri dohvaćanju sudionika",
    "Could not send invitation to {actorId}" : "Nije moguće poslati pozivnicu za {actorId}",
    "Invitations sent" : "Pozivnice su poslane",
    "Error occurred when sending invitations" : "Došlo je do pogreške pri slanju pozivnica",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud Talk ne podržava trenutni preglednik. Preuzmite najnoviju inačicu preglednika Mozilla Firefox, Microsoft Edge, Google Chrome, Opera ili Apple Safari.",
    "Lost connection to signaling server. Trying to reconnect." : "Veza sa signalnim poslužiteljem je prekinuta. Pokušavam se ponovno povezati.",
    "Establishing signaling connection is taking longer than expected …" : "Uspostavljanje signalne veze traje duže od očekivanog…",
    "Failed to establish signaling connection. Retrying …" : "Signalna veza nije uspostavljena. Pokušavam ponovo…",
    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "Signalna veza nije uspostavljena. Nešto nije u redu u konfiguraciji signalnog poslužitelja",
    "Please reload the page." : "Ponovno učitajte stranicu.",
    "Do not disturb" : "Ne ometaj",
    "Away" : "Odsutan",
    "Microphone {number}" : "Mikrofon {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Zvučnik {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Pričate dok je utišan zvuk, isključite utišavanje zvuka kako bi vas čuli drugi sudionici razgovora",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Nije uspostavljena veza s najmanje jednim sudionikom. Vjerojatno vam je potreban poslužitelj TURN. Obratite se svom administratoru i zatražite da omogući korištenje poslužitelja TURN u skladu s {linkstart}ovom dokumentacijom{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Radnja traje duže od očekivanog. Jesu li postavljena (ili odbijena) dopuštenja za pristupanje medijima? Ako jesu, ponovno pokrenite preglednik jer nema prijenosa zvuka i videosignala",
    "Access to microphone & camera is only possible with HTTPS" : "Pristup mikrofonu i kameri moguć je samo putem HTTPS-a",
    "Please move your setup to HTTPS" : "Prebacite postavku na HTTPS",
    "Access to microphone & camera was denied" : "Pristup mikrofonu i kameri je odbijen",
    "WebRTC is not supported in your browser" : "Vaš preglednik ne podržava WebRTC",
    "Please use a different browser like Firefox or Chrome" : "Koristite se drugim preglednikom kao što je Firefox ili Chrome",
    "Error while accessing microphone & camera" : "Došlo je do pogreške pri pristupanju mikrofonu i kameri",
    "The password is wrong. Try again." : "Pogrešna zaporka. Pokušajte ponovno.",
    "%s Talk on your mobile devices" : "%s aplikacija Talk na vašim mobilnim uređajima",
    "Join conversations at any time, anywhere, on any device." : "Pridružite se razgovorima u bilo koje vrijeme, bilo gdje, na bilo kojem uređaju.",
    "Android app" : "Aplikacija za Android",
    "iOS app" : "Aplikacija za iOS",
    "__language_name__" : "Hrvatski",
    "Tasks" : "Zadaci",
    "Notes" : "Bilješke",
    "You tried to call {user}" : "Pokušali ste nazvati {user}",
    "%s invited you to a conversation." : "%s vas je pozvao u razgovor.",
    "You were invited to a conversation." : "Pozvani ste u razgovor.",
    "Click the button below to join." : "Kliknite gumb ispod za pridruživanje.",
    "Join »%s«" : "Pridruži se »%s«",
    "{user} invited you to a private conversation" : "{user} vas je pozvao u privatni razgovor",
    "Always show the device preview screen before joining a call in this conversation." : "Uvijek prikažite zaslon za pretpregled uređaja prije pridruživanja pozivu u ovom razgovoru.",
    "Copy conversation link" : "Kopiraj poveznicu za razgovor",
    "Close" : "Zatvori",
    "Choose devices" : "Odaberi uređaje",
    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu prije upućivanja ili pridruživanja razgovoru.",
    "Blur background" : "Zamuti pozadinu",
    "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk je ažuriran, ponovno učitajte stranicu",
    "An error happened when trying to share your file" : "Došlo je do pogreške pri pokušaju dijeljenja datoteke",
    "Failed to join the conversation. Try to reload the page." : "Pridruživanje razgovoru nije uspjelo. Pokušajte ponovno učitati stranicu.",
    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud je u načinu održavanja, ponovno učitajte stranicu",
    "Lost connection to signaling server. Try to reload the page manually." : "Veza sa signalnim poslužiteljem je prekinuta. Pokušajte ponovno učitati stranicu."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
